@@ -17,8 +17,8 @@ from .launchers.launch_dast_scanner import run_dast_scanner
 from .launchers.launch_sca_scanner import run_sca_scanner
 from .launchers.docker_util import get_formated_timestamp, create_skenoutput_folder, delete_skenoutput_folder
 
-SKEN_SERVER_BASE_URL = 'https://cli.sken.ai/cliapi/v1'
-#SKEN_SERVER_BASE_URL = 'http://localhost:8080/cliapi/v1'
+SKEN_SERVER_BASE_URL = 'https://cli.sken.ai/api/cli/v1'
+#SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1'
 LANGUAGES = ['ruby', 'javascript', 'typescript', 'python', 'php',
              'java', 'nodejs', 'license', 'go', 'python2']
 SCANNERS = ['sast', 'dast', 'sca']
